@@ -11,7 +11,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,11 +46,13 @@
 #include <iostream>
 using namespace std;
 #include <QApplication>
+#include <QFileInfo>
 #include <QMessageBox>
+#include <QObject>
 #include <QSplashScreen>
-#include "WebcamSource.h"
 #include "Common.h"
 #include "MainWindow.h"
+#include "WebcamSource.h"
 #include "gmic.h"
 
 #ifdef _IS_UNIX_
@@ -63,14 +65,14 @@ void onSigQuit(int)
 }
 #endif
 
-int main( int argc, char *argv[] )
+int main(int argc, char * argv[])
 {
 #ifdef _IS_UNIX_
-  signal(SIGQUIT,onSigQuit);
-  signal(SIGINT,onSigQuit);
+  signal(SIGQUIT, onSigQuit);
+  signal(SIGINT, onSigQuit);
 #endif
-  QApplication app( argc, argv );
-  app.setWindowIcon( QIcon(":images/gmic_hat.png") );
+  QApplication app(argc, argv);
+  app.setWindowIcon(QIcon(":images/gmic_hat.png"));
   QCoreApplication::setOrganizationName("GREYC");
   QCoreApplication::setOrganizationDomain("greyc.fr");
   QCoreApplication::setApplicationName("ZArt");
@@ -79,14 +81,14 @@ int main( int argc, char *argv[] )
   QStringList args = app.arguments();
   QStringList::iterator it = args.begin();
   while (it != args.end()) {
-    if ( it->startsWith("-h") || it->startsWith("--help") ) {
+    if (it->startsWith("-h") || it->startsWith("--help")) {
       cout << "Usage:" << endl
-           << "       "
-           << QFileInfo(argv[0]).baseName().toLatin1().constData()
-          << " [options]" << endl
-          << "  " << "Options: " << endl
-          << "      --help | -h   : print this help." << endl
-          << endl;
+           << "       " << QFileInfo(argv[0]).baseName().toLatin1().constData() << " [options]" << endl
+           << "  "
+           << "Options: " << endl
+           << "      --clear-cams  : Clear webcam cache." << endl
+           << "      --help | -h   : print this help." << endl
+           << endl;
       exit(EXIT_SUCCESS);
     }
     ++it;
@@ -94,12 +96,28 @@ int main( int argc, char *argv[] )
   QSplashScreen splashScreen(QPixmap(":/images/splash.png"));
   splashScreen.show();
   app.processEvents();
-  WebcamSource::retrieveWebcamResolutions(WebcamSource::getWebcamList(),
-                                          &splashScreen);
-  if ( ! gmic::init_rc() ) {
+  if (QApplication::arguments().contains("--clear-cams")) {
+    WebcamSource::clearSavedSettings();
+  }
+  WebcamSource::retrieveWebcamResolutions(WebcamSource::getWebcamList(), &splashScreen);
+  if (!gmic::init_rc()) {
     cerr << "[ZArt] Warning: Could not create resources directory.\n";
   }
   MainWindow mainWindow;
+  if ((args.size() > 1) && QFileInfo(args.back()).isReadable()) {
+    QStringList imagesExtensions = QString("bmp gif jpg png pbm pgm ppm xbm xpm svg").split(" ");
+    for (const QString & ext : imagesExtensions) {
+      if (args.back().endsWith("." + ext)) {
+        mainWindow.setInputImage(args.back());
+      }
+    }
+    QStringList videoExtensions = QString("avi mpg mpeg").split(" ");
+    for (const QString & ext : imagesExtensions) {
+      if (args.back().endsWith("." + ext)) {
+        mainWindow.setInputVideo(args.back());
+      }
+    }
+  }
   mainWindow.show();
   splashScreen.finish(&mainWindow);
   return app.exec();
